@@ -22,7 +22,11 @@ github.com/xiyaowong/python-iotbot
         bot.run()
 """
 
-from . import refine as refine_message  # 兼容旧版本，以后可能删除
+try:
+    import ujson as json
+except ImportError:
+    import json
+
 from .action import Action
 from .client import IOTBOT
 from .model import EventMsg, FriendMsg, GroupMsg
